@@ -1,3 +1,5 @@
+function _aws_cdk_aws_iotevents_actions_SetVariableAction(p) {
+}
 function _aws_cdk_aws_iotevents_actions_LambdaInvokeAction(p) {
 }
 function print(name, deprecationMessage) {
@@ -15,5 +17,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iotevents_actions_LambdaInvokeAction };
+module.exports = { print, _aws_cdk_aws_iotevents_actions_SetVariableAction, _aws_cdk_aws_iotevents_actions_LambdaInvokeAction };
 module.exports.DeprecationError = DeprecationError;
